Installation
------------

See the `INSTALL.md` document.

Online documentation
--------------------

- Check the [Web site](https://atcollab.github.io/at/)
- Check the [WIKI](https://github.com/atcollab/at/wiki)
